# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['TrunkArgs', 'Trunk']

@pulumi.input_type
class TrunkArgs:
    def __init__(__self__, *,
                 port_id: pulumi.Input[builtins.str],
                 admin_state_up: Optional[pulumi.Input[builtins.bool]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 region: Optional[pulumi.Input[builtins.str]] = None,
                 sub_ports: Optional[pulumi.Input[Sequence[pulumi.Input['TrunkSubPortArgs']]]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 tenant_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a Trunk resource.
        :param pulumi.Input[builtins.str] port_id: The ID of the port to be used as the parent port of the
               trunk. This is the port that should be used as the compute instance network
               port. Changing this creates a new trunk.
        :param pulumi.Input[builtins.bool] admin_state_up: Administrative up/down status for the trunk
               (must be "true" or "false" if provided). Changing this updates the
               `admin_state_up` of an existing trunk.
        :param pulumi.Input[builtins.str] description: Human-readable description of the trunk. Changing this
               updates the name of the existing trunk.
        :param pulumi.Input[builtins.str] name: A unique name for the trunk. Changing this
               updates the `name` of an existing trunk.
        :param pulumi.Input[builtins.str] region: The region in which to obtain the V2 networking client.
               A networking client is needed to create a trunk. If omitted, the
               `region` argument of the provider is used. Changing this creates a new
               trunk.
        :param pulumi.Input[Sequence[pulumi.Input['TrunkSubPortArgs']]] sub_ports: The set of ports that will be made subports of the trunk.
               The structure of each subport is described below.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] tags: A set of string tags for the port.
        :param pulumi.Input[builtins.str] tenant_id: The owner of the Trunk. Required if admin wants
               to create a trunk on behalf of another tenant. Changing this creates a new trunk.
        """
        pulumi.set(__self__, "port_id", port_id)
        if admin_state_up is not None:
            pulumi.set(__self__, "admin_state_up", admin_state_up)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if sub_ports is not None:
            pulumi.set(__self__, "sub_ports", sub_ports)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if tenant_id is not None:
            pulumi.set(__self__, "tenant_id", tenant_id)

    @property
    @pulumi.getter(name="portId")
    def port_id(self) -> pulumi.Input[builtins.str]:
        """
        The ID of the port to be used as the parent port of the
        trunk. This is the port that should be used as the compute instance network
        port. Changing this creates a new trunk.
        """
        return pulumi.get(self, "port_id")

    @port_id.setter
    def port_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "port_id", value)

    @property
    @pulumi.getter(name="adminStateUp")
    def admin_state_up(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Administrative up/down status for the trunk
        (must be "true" or "false" if provided). Changing this updates the
        `admin_state_up` of an existing trunk.
        """
        return pulumi.get(self, "admin_state_up")

    @admin_state_up.setter
    def admin_state_up(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "admin_state_up", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Human-readable description of the trunk. Changing this
        updates the name of the existing trunk.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        A unique name for the trunk. Changing this
        updates the `name` of an existing trunk.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The region in which to obtain the V2 networking client.
        A networking client is needed to create a trunk. If omitted, the
        `region` argument of the provider is used. Changing this creates a new
        trunk.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "region", value)

    @property
    @pulumi.getter(name="subPorts")
    def sub_ports(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['TrunkSubPortArgs']]]]:
        """
        The set of ports that will be made subports of the trunk.
        The structure of each subport is described below.
        """
        return pulumi.get(self, "sub_ports")

    @sub_ports.setter
    def sub_ports(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['TrunkSubPortArgs']]]]):
        pulumi.set(self, "sub_ports", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        A set of string tags for the port.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="tenantId")
    def tenant_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The owner of the Trunk. Required if admin wants
        to create a trunk on behalf of another tenant. Changing this creates a new trunk.
        """
        return pulumi.get(self, "tenant_id")

    @tenant_id.setter
    def tenant_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "tenant_id", value)


@pulumi.input_type
class _TrunkState:
    def __init__(__self__, *,
                 admin_state_up: Optional[pulumi.Input[builtins.bool]] = None,
                 all_tags: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 port_id: Optional[pulumi.Input[builtins.str]] = None,
                 region: Optional[pulumi.Input[builtins.str]] = None,
                 sub_ports: Optional[pulumi.Input[Sequence[pulumi.Input['TrunkSubPortArgs']]]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 tenant_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering Trunk resources.
        :param pulumi.Input[builtins.bool] admin_state_up: Administrative up/down status for the trunk
               (must be "true" or "false" if provided). Changing this updates the
               `admin_state_up` of an existing trunk.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] all_tags: The collection of tags assigned on the trunk, which have been
               explicitly and implicitly added.
        :param pulumi.Input[builtins.str] description: Human-readable description of the trunk. Changing this
               updates the name of the existing trunk.
        :param pulumi.Input[builtins.str] name: A unique name for the trunk. Changing this
               updates the `name` of an existing trunk.
        :param pulumi.Input[builtins.str] port_id: The ID of the port to be used as the parent port of the
               trunk. This is the port that should be used as the compute instance network
               port. Changing this creates a new trunk.
        :param pulumi.Input[builtins.str] region: The region in which to obtain the V2 networking client.
               A networking client is needed to create a trunk. If omitted, the
               `region` argument of the provider is used. Changing this creates a new
               trunk.
        :param pulumi.Input[Sequence[pulumi.Input['TrunkSubPortArgs']]] sub_ports: The set of ports that will be made subports of the trunk.
               The structure of each subport is described below.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] tags: A set of string tags for the port.
        :param pulumi.Input[builtins.str] tenant_id: The owner of the Trunk. Required if admin wants
               to create a trunk on behalf of another tenant. Changing this creates a new trunk.
        """
        if admin_state_up is not None:
            pulumi.set(__self__, "admin_state_up", admin_state_up)
        if all_tags is not None:
            pulumi.set(__self__, "all_tags", all_tags)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if port_id is not None:
            pulumi.set(__self__, "port_id", port_id)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if sub_ports is not None:
            pulumi.set(__self__, "sub_ports", sub_ports)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if tenant_id is not None:
            pulumi.set(__self__, "tenant_id", tenant_id)

    @property
    @pulumi.getter(name="adminStateUp")
    def admin_state_up(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Administrative up/down status for the trunk
        (must be "true" or "false" if provided). Changing this updates the
        `admin_state_up` of an existing trunk.
        """
        return pulumi.get(self, "admin_state_up")

    @admin_state_up.setter
    def admin_state_up(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "admin_state_up", value)

    @property
    @pulumi.getter(name="allTags")
    def all_tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        The collection of tags assigned on the trunk, which have been
        explicitly and implicitly added.
        """
        return pulumi.get(self, "all_tags")

    @all_tags.setter
    def all_tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "all_tags", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Human-readable description of the trunk. Changing this
        updates the name of the existing trunk.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        A unique name for the trunk. Changing this
        updates the `name` of an existing trunk.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="portId")
    def port_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the port to be used as the parent port of the
        trunk. This is the port that should be used as the compute instance network
        port. Changing this creates a new trunk.
        """
        return pulumi.get(self, "port_id")

    @port_id.setter
    def port_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "port_id", value)

    @property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The region in which to obtain the V2 networking client.
        A networking client is needed to create a trunk. If omitted, the
        `region` argument of the provider is used. Changing this creates a new
        trunk.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "region", value)

    @property
    @pulumi.getter(name="subPorts")
    def sub_ports(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['TrunkSubPortArgs']]]]:
        """
        The set of ports that will be made subports of the trunk.
        The structure of each subport is described below.
        """
        return pulumi.get(self, "sub_ports")

    @sub_ports.setter
    def sub_ports(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['TrunkSubPortArgs']]]]):
        pulumi.set(self, "sub_ports", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        A set of string tags for the port.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="tenantId")
    def tenant_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The owner of the Trunk. Required if admin wants
        to create a trunk on behalf of another tenant. Changing this creates a new trunk.
        """
        return pulumi.get(self, "tenant_id")

    @tenant_id.setter
    def tenant_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "tenant_id", value)


class Trunk(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 admin_state_up: Optional[pulumi.Input[builtins.bool]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 port_id: Optional[pulumi.Input[builtins.str]] = None,
                 region: Optional[pulumi.Input[builtins.str]] = None,
                 sub_ports: Optional[pulumi.Input[Sequence[pulumi.Input[Union['TrunkSubPortArgs', 'TrunkSubPortArgsDict']]]]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 tenant_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Manages a networking V2 trunk resource within OpenStack.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_openstack as openstack

        network1 = openstack.networking.Network("network_1",
            name="network_1",
            admin_state_up=True)
        subnet1 = openstack.networking.Subnet("subnet_1",
            name="subnet_1",
            network_id=network1.id,
            cidr="192.168.1.0/24",
            ip_version=4,
            enable_dhcp=True,
            no_gateway=True)
        parent_port1 = openstack.networking.Port("parent_port_1",
            name="parent_port_1",
            network_id=network1.id,
            admin_state_up=True,
            opts = pulumi.ResourceOptions(depends_on=[subnet1]))
        subport1 = openstack.networking.Port("subport_1",
            name="subport_1",
            network_id=network1.id,
            admin_state_up=True,
            opts = pulumi.ResourceOptions(depends_on=[subnet1]))
        trunk1 = openstack.networking.Trunk("trunk_1",
            name="trunk_1",
            admin_state_up=True,
            port_id=parent_port1.id,
            sub_ports=[{
                "port_id": subport1.id,
                "segmentation_id": 1,
                "segmentation_type": "vlan",
            }])
        instance1 = openstack.compute.Instance("instance_1",
            name="instance_1",
            security_groups=["default"],
            networks=[{
                "port": trunk1.port_id,
            }])
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.bool] admin_state_up: Administrative up/down status for the trunk
               (must be "true" or "false" if provided). Changing this updates the
               `admin_state_up` of an existing trunk.
        :param pulumi.Input[builtins.str] description: Human-readable description of the trunk. Changing this
               updates the name of the existing trunk.
        :param pulumi.Input[builtins.str] name: A unique name for the trunk. Changing this
               updates the `name` of an existing trunk.
        :param pulumi.Input[builtins.str] port_id: The ID of the port to be used as the parent port of the
               trunk. This is the port that should be used as the compute instance network
               port. Changing this creates a new trunk.
        :param pulumi.Input[builtins.str] region: The region in which to obtain the V2 networking client.
               A networking client is needed to create a trunk. If omitted, the
               `region` argument of the provider is used. Changing this creates a new
               trunk.
        :param pulumi.Input[Sequence[pulumi.Input[Union['TrunkSubPortArgs', 'TrunkSubPortArgsDict']]]] sub_ports: The set of ports that will be made subports of the trunk.
               The structure of each subport is described below.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] tags: A set of string tags for the port.
        :param pulumi.Input[builtins.str] tenant_id: The owner of the Trunk. Required if admin wants
               to create a trunk on behalf of another tenant. Changing this creates a new trunk.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: TrunkArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages a networking V2 trunk resource within OpenStack.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_openstack as openstack

        network1 = openstack.networking.Network("network_1",
            name="network_1",
            admin_state_up=True)
        subnet1 = openstack.networking.Subnet("subnet_1",
            name="subnet_1",
            network_id=network1.id,
            cidr="192.168.1.0/24",
            ip_version=4,
            enable_dhcp=True,
            no_gateway=True)
        parent_port1 = openstack.networking.Port("parent_port_1",
            name="parent_port_1",
            network_id=network1.id,
            admin_state_up=True,
            opts = pulumi.ResourceOptions(depends_on=[subnet1]))
        subport1 = openstack.networking.Port("subport_1",
            name="subport_1",
            network_id=network1.id,
            admin_state_up=True,
            opts = pulumi.ResourceOptions(depends_on=[subnet1]))
        trunk1 = openstack.networking.Trunk("trunk_1",
            name="trunk_1",
            admin_state_up=True,
            port_id=parent_port1.id,
            sub_ports=[{
                "port_id": subport1.id,
                "segmentation_id": 1,
                "segmentation_type": "vlan",
            }])
        instance1 = openstack.compute.Instance("instance_1",
            name="instance_1",
            security_groups=["default"],
            networks=[{
                "port": trunk1.port_id,
            }])
        ```

        :param str resource_name: The name of the resource.
        :param TrunkArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(TrunkArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 admin_state_up: Optional[pulumi.Input[builtins.bool]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 port_id: Optional[pulumi.Input[builtins.str]] = None,
                 region: Optional[pulumi.Input[builtins.str]] = None,
                 sub_ports: Optional[pulumi.Input[Sequence[pulumi.Input[Union['TrunkSubPortArgs', 'TrunkSubPortArgsDict']]]]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 tenant_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = TrunkArgs.__new__(TrunkArgs)

            __props__.__dict__["admin_state_up"] = admin_state_up
            __props__.__dict__["description"] = description
            __props__.__dict__["name"] = name
            if port_id is None and not opts.urn:
                raise TypeError("Missing required property 'port_id'")
            __props__.__dict__["port_id"] = port_id
            __props__.__dict__["region"] = region
            __props__.__dict__["sub_ports"] = sub_ports
            __props__.__dict__["tags"] = tags
            __props__.__dict__["tenant_id"] = tenant_id
            __props__.__dict__["all_tags"] = None
        super(Trunk, __self__).__init__(
            'openstack:networking/trunk:Trunk',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            admin_state_up: Optional[pulumi.Input[builtins.bool]] = None,
            all_tags: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            name: Optional[pulumi.Input[builtins.str]] = None,
            port_id: Optional[pulumi.Input[builtins.str]] = None,
            region: Optional[pulumi.Input[builtins.str]] = None,
            sub_ports: Optional[pulumi.Input[Sequence[pulumi.Input[Union['TrunkSubPortArgs', 'TrunkSubPortArgsDict']]]]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            tenant_id: Optional[pulumi.Input[builtins.str]] = None) -> 'Trunk':
        """
        Get an existing Trunk resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.bool] admin_state_up: Administrative up/down status for the trunk
               (must be "true" or "false" if provided). Changing this updates the
               `admin_state_up` of an existing trunk.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] all_tags: The collection of tags assigned on the trunk, which have been
               explicitly and implicitly added.
        :param pulumi.Input[builtins.str] description: Human-readable description of the trunk. Changing this
               updates the name of the existing trunk.
        :param pulumi.Input[builtins.str] name: A unique name for the trunk. Changing this
               updates the `name` of an existing trunk.
        :param pulumi.Input[builtins.str] port_id: The ID of the port to be used as the parent port of the
               trunk. This is the port that should be used as the compute instance network
               port. Changing this creates a new trunk.
        :param pulumi.Input[builtins.str] region: The region in which to obtain the V2 networking client.
               A networking client is needed to create a trunk. If omitted, the
               `region` argument of the provider is used. Changing this creates a new
               trunk.
        :param pulumi.Input[Sequence[pulumi.Input[Union['TrunkSubPortArgs', 'TrunkSubPortArgsDict']]]] sub_ports: The set of ports that will be made subports of the trunk.
               The structure of each subport is described below.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] tags: A set of string tags for the port.
        :param pulumi.Input[builtins.str] tenant_id: The owner of the Trunk. Required if admin wants
               to create a trunk on behalf of another tenant. Changing this creates a new trunk.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _TrunkState.__new__(_TrunkState)

        __props__.__dict__["admin_state_up"] = admin_state_up
        __props__.__dict__["all_tags"] = all_tags
        __props__.__dict__["description"] = description
        __props__.__dict__["name"] = name
        __props__.__dict__["port_id"] = port_id
        __props__.__dict__["region"] = region
        __props__.__dict__["sub_ports"] = sub_ports
        __props__.__dict__["tags"] = tags
        __props__.__dict__["tenant_id"] = tenant_id
        return Trunk(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="adminStateUp")
    def admin_state_up(self) -> pulumi.Output[Optional[builtins.bool]]:
        """
        Administrative up/down status for the trunk
        (must be "true" or "false" if provided). Changing this updates the
        `admin_state_up` of an existing trunk.
        """
        return pulumi.get(self, "admin_state_up")

    @property
    @pulumi.getter(name="allTags")
    def all_tags(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        The collection of tags assigned on the trunk, which have been
        explicitly and implicitly added.
        """
        return pulumi.get(self, "all_tags")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Human-readable description of the trunk. Changing this
        updates the name of the existing trunk.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[builtins.str]:
        """
        A unique name for the trunk. Changing this
        updates the `name` of an existing trunk.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="portId")
    def port_id(self) -> pulumi.Output[builtins.str]:
        """
        The ID of the port to be used as the parent port of the
        trunk. This is the port that should be used as the compute instance network
        port. Changing this creates a new trunk.
        """
        return pulumi.get(self, "port_id")

    @property
    @pulumi.getter
    def region(self) -> pulumi.Output[builtins.str]:
        """
        The region in which to obtain the V2 networking client.
        A networking client is needed to create a trunk. If omitted, the
        `region` argument of the provider is used. Changing this creates a new
        trunk.
        """
        return pulumi.get(self, "region")

    @property
    @pulumi.getter(name="subPorts")
    def sub_ports(self) -> pulumi.Output[Optional[Sequence['outputs.TrunkSubPort']]]:
        """
        The set of ports that will be made subports of the trunk.
        The structure of each subport is described below.
        """
        return pulumi.get(self, "sub_ports")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Sequence[builtins.str]]]:
        """
        A set of string tags for the port.
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="tenantId")
    def tenant_id(self) -> pulumi.Output[builtins.str]:
        """
        The owner of the Trunk. Required if admin wants
        to create a trunk on behalf of another tenant. Changing this creates a new trunk.
        """
        return pulumi.get(self, "tenant_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

import types

__config__ = pulumi.Config('openstack')


class _ExportableConfig(types.ModuleType):
    @property
    def allow_reauth(self) -> Optional[bool]:
        """
        If set to `false`, OpenStack authorization won't be perfomed automatically, if the initial auth token get expired.
        Defaults to `true`
        """
        return __config__.get_bool('allowReauth') or _utilities.get_env_bool('OS_ALLOW_REAUTH')

    @property
    def application_credential_id(self) -> Optional[str]:
        """
        Application Credential ID to login with.
        """
        return __config__.get('applicationCredentialId')

    @property
    def application_credential_name(self) -> Optional[str]:
        """
        Application Credential name to login with.
        """
        return __config__.get('applicationCredentialName')

    @property
    def application_credential_secret(self) -> Optional[str]:
        """
        Application Credential secret to login with.
        """
        return __config__.get('applicationCredentialSecret')

    @property
    def auth_url(self) -> Optional[str]:
        """
        The Identity authentication URL.
        """
        return __config__.get('authUrl')

    @property
    def cacert_file(self) -> Optional[str]:
        """
        A Custom CA certificate.
        """
        return __config__.get('cacertFile')

    @property
    def cert(self) -> Optional[str]:
        """
        A client certificate to authenticate with.
        """
        return __config__.get('cert')

    @property
    def cloud(self) -> Optional[str]:
        """
        An entry in a `clouds.yaml` file to use.
        """
        return __config__.get('cloud') or _utilities.get_env('OS_CLOUD')

    @property
    def default_domain(self) -> Optional[str]:
        """
        The name of the Domain ID to scope to if no other domain is specified. Defaults to `default` (Identity v3).
        """
        return __config__.get('defaultDomain')

    @property
    def delayed_auth(self) -> Optional[bool]:
        """
        If set to `false`, OpenStack authorization will be perfomed, every time the service provider client is called. Defaults
        to `true`.
        """
        return __config__.get_bool('delayedAuth') or _utilities.get_env_bool('OS_DELAYED_AUTH')

    @property
    def disable_no_cache_header(self) -> Optional[bool]:
        """
        If set to `true`, the HTTP `Cache-Control: no-cache` header will not be added by default to all API requests.
        """
        return __config__.get_bool('disableNoCacheHeader')

    @property
    def domain_id(self) -> Optional[str]:
        """
        The ID of the Domain to scope to (Identity v3).
        """
        return __config__.get('domainId')

    @property
    def domain_name(self) -> Optional[str]:
        """
        The name of the Domain to scope to (Identity v3).
        """
        return __config__.get('domainName')

    @property
    def enable_logging(self) -> Optional[bool]:
        """
        Outputs very verbose logs with all calls made to and responses from OpenStack
        """
        return __config__.get_bool('enableLogging')

    @property
    def endpoint_overrides(self) -> Optional[str]:
        """
        A map of services with an endpoint to override what was from the Keystone catalog
        """
        return __config__.get('endpointOverrides')

    @property
    def endpoint_type(self) -> Optional[str]:
        return __config__.get('endpointType') or _utilities.get_env('OS_ENDPOINT_TYPE')

    @property
    def insecure(self) -> Optional[bool]:
        """
        Trust self-signed certificates.
        """
        return __config__.get_bool('insecure') or _utilities.get_env_bool('OS_INSECURE')

    @property
    def key(self) -> Optional[str]:
        """
        A client private key to authenticate with.
        """
        return __config__.get('key')

    @property
    def max_retries(self) -> Optional[int]:
        """
        How many times HTTP connection should be retried until giving up.
        """
        return __config__.get_int('maxRetries')

    @property
    def password(self) -> Optional[str]:
        """
        Password to login with.
        """
        return __config__.get('password')

    @property
    def project_domain_id(self) -> Optional[str]:
        """
        The ID of the domain where the proejct resides (Identity v3).
        """
        return __config__.get('projectDomainId')

    @property
    def project_domain_name(self) -> Optional[str]:
        """
        The name of the domain where the project resides (Identity v3).
        """
        return __config__.get('projectDomainName')

    @property
    def region(self) -> Optional[str]:
        """
        The OpenStack region to connect to.
        """
        return __config__.get('region') or _utilities.get_env('OS_REGION_NAME')

    @property
    def swauth(self) -> Optional[bool]:
        """
        Use Swift's authentication system instead of Keystone. Only used for interaction with Swift.
        """
        return __config__.get_bool('swauth') or _utilities.get_env_bool('OS_SWAUTH')

    @property
    def system_scope(self) -> Optional[bool]:
        """
        If set to `true`, system scoped authorization will be enabled. Defaults to `false` (Identity v3).
        """
        return __config__.get_bool('systemScope')

    @property
    def tenant_id(self) -> Optional[str]:
        """
        The ID of the Tenant (Identity v2) or Project (Identity v3) to login with.
        """
        return __config__.get('tenantId')

    @property
    def tenant_name(self) -> Optional[str]:
        """
        The name of the Tenant (Identity v2) or Project (Identity v3) to login with.
        """
        return __config__.get('tenantName')

    @property
    def token(self) -> Optional[str]:
        """
        Authentication token to use as an alternative to username/password.
        """
        return __config__.get('token')

    @property
    def user_domain_id(self) -> Optional[str]:
        """
        The ID of the domain where the user resides (Identity v3).
        """
        return __config__.get('userDomainId')

    @property
    def user_domain_name(self) -> Optional[str]:
        """
        The name of the domain where the user resides (Identity v3).
        """
        return __config__.get('userDomainName')

    @property
    def user_id(self) -> Optional[str]:
        """
        User ID to login with.
        """
        return __config__.get('userId')

    @property
    def user_name(self) -> Optional[str]:
        """
        Username to login with.
        """
        return __config__.get('userName')




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'ConfigurationConfiguration',
    'ConfigurationDatastore',
    'InstanceDatabase',
    'InstanceDatastore',
    'InstanceNetwork',
    'InstanceUser',
]

@pulumi.output_type
class ConfigurationConfiguration(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "stringType":
            suggest = "string_type"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ConfigurationConfiguration. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ConfigurationConfiguration.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ConfigurationConfiguration.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 name: builtins.str,
                 value: builtins.str,
                 string_type: Optional[builtins.bool] = None):
        """
        :param builtins.str name: Configuration parameter name. Changing this creates a new resource.
        :param builtins.str value: Configuration parameter value. Changing this creates a new resource.
        :param builtins.bool string_type: Whether or not to store configuration parameter value as string. Changing this creates a new resource. See the below note for more information.
        """
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "value", value)
        if string_type is not None:
            pulumi.set(__self__, "string_type", string_type)

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        Configuration parameter name. Changing this creates a new resource.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def value(self) -> builtins.str:
        """
        Configuration parameter value. Changing this creates a new resource.
        """
        return pulumi.get(self, "value")

    @property
    @pulumi.getter(name="stringType")
    def string_type(self) -> Optional[builtins.bool]:
        """
        Whether or not to store configuration parameter value as string. Changing this creates a new resource. See the below note for more information.
        """
        return pulumi.get(self, "string_type")


@pulumi.output_type
class ConfigurationDatastore(dict):
    def __init__(__self__, *,
                 type: builtins.str,
                 version: builtins.str):
        """
        :param builtins.str type: Database engine type to be used with this configuration. Changing this creates a new resource.
        :param builtins.str version: Version of database engine type to be used with this configuration. Changing this creates a new resource.
        """
        pulumi.set(__self__, "type", type)
        pulumi.set(__self__, "version", version)

    @property
    @pulumi.getter
    def type(self) -> builtins.str:
        """
        Database engine type to be used with this configuration. Changing this creates a new resource.
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter
    def version(self) -> builtins.str:
        """
        Version of database engine type to be used with this configuration. Changing this creates a new resource.
        """
        return pulumi.get(self, "version")


@pulumi.output_type
class InstanceDatabase(dict):
    def __init__(__self__, *,
                 name: builtins.str,
                 charset: Optional[builtins.str] = None,
                 collate: Optional[builtins.str] = None):
        """
        :param builtins.str name: Database to be created on new instance. Changing this creates a
               new instance.
        :param builtins.str charset: Database character set. Changing this creates a
               new instance.
        :param builtins.str collate: Database collation. Changing this creates a new instance.
        """
        pulumi.set(__self__, "name", name)
        if charset is not None:
            pulumi.set(__self__, "charset", charset)
        if collate is not None:
            pulumi.set(__self__, "collate", collate)

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        Database to be created on new instance. Changing this creates a
        new instance.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def charset(self) -> Optional[builtins.str]:
        """
        Database character set. Changing this creates a
        new instance.
        """
        return pulumi.get(self, "charset")

    @property
    @pulumi.getter
    def collate(self) -> Optional[builtins.str]:
        """
        Database collation. Changing this creates a new instance.
        """
        return pulumi.get(self, "collate")


@pulumi.output_type
class InstanceDatastore(dict):
    def __init__(__self__, *,
                 type: builtins.str,
                 version: builtins.str):
        """
        :param builtins.str type: Database engine type to be used in new instance. Changing this
               creates a new instance.
        :param builtins.str version: Version of database engine type to be used in new instance.
               Changing this creates a new instance.
        """
        pulumi.set(__self__, "type", type)
        pulumi.set(__self__, "version", version)

    @property
    @pulumi.getter
    def type(self) -> builtins.str:
        """
        Database engine type to be used in new instance. Changing this
        creates a new instance.
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter
    def version(self) -> builtins.str:
        """
        Version of database engine type to be used in new instance.
        Changing this creates a new instance.
        """
        return pulumi.get(self, "version")


@pulumi.output_type
class InstanceNetwork(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "fixedIpV4":
            suggest = "fixed_ip_v4"
        elif key == "fixedIpV6":
            suggest = "fixed_ip_v6"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in InstanceNetwork. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        InstanceNetwork.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        InstanceNetwork.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 fixed_ip_v4: Optional[builtins.str] = None,
                 fixed_ip_v6: Optional[builtins.str] = None,
                 port: Optional[builtins.str] = None,
                 uuid: Optional[builtins.str] = None):
        """
        :param builtins.str fixed_ip_v4: Specifies a fixed IPv4 address to be used on this
               network. Changing this creates a new instance.
        :param builtins.str fixed_ip_v6: Specifies a fixed IPv6 address to be used on this
               network. Changing this creates a new instance.
        :param builtins.str port: The port UUID of a
               network to attach to the instance. Changing this creates a new instance.
        :param builtins.str uuid: The network UUID to
               attach to the instance. Changing this creates a new instance.
        """
        if fixed_ip_v4 is not None:
            pulumi.set(__self__, "fixed_ip_v4", fixed_ip_v4)
        if fixed_ip_v6 is not None:
            pulumi.set(__self__, "fixed_ip_v6", fixed_ip_v6)
        if port is not None:
            pulumi.set(__self__, "port", port)
        if uuid is not None:
            pulumi.set(__self__, "uuid", uuid)

    @property
    @pulumi.getter(name="fixedIpV4")
    def fixed_ip_v4(self) -> Optional[builtins.str]:
        """
        Specifies a fixed IPv4 address to be used on this
        network. Changing this creates a new instance.
        """
        return pulumi.get(self, "fixed_ip_v4")

    @property
    @pulumi.getter(name="fixedIpV6")
    def fixed_ip_v6(self) -> Optional[builtins.str]:
        """
        Specifies a fixed IPv6 address to be used on this
        network. Changing this creates a new instance.
        """
        return pulumi.get(self, "fixed_ip_v6")

    @property
    @pulumi.getter
    def port(self) -> Optional[builtins.str]:
        """
        The port UUID of a
        network to attach to the instance. Changing this creates a new instance.
        """
        return pulumi.get(self, "port")

    @property
    @pulumi.getter
    def uuid(self) -> Optional[builtins.str]:
        """
        The network UUID to
        attach to the instance. Changing this creates a new instance.
        """
        return pulumi.get(self, "uuid")


@pulumi.output_type
class InstanceUser(dict):
    def __init__(__self__, *,
                 name: builtins.str,
                 databases: Optional[Sequence[builtins.str]] = None,
                 host: Optional[builtins.str] = None,
                 password: Optional[builtins.str] = None):
        """
        :param builtins.str name: Username to be created on new instance. Changing this creates a
               new instance.
        :param Sequence[builtins.str] databases: A list of databases that user will have access to. If not specified,
               user has access to all databases on th einstance. Changing this creates a new instance.
        :param builtins.str host: An ip address or % sign indicating what ip addresses can connect with
               this user credentials. Changing this creates a new instance.
        :param builtins.str password: User's password. Changing this creates a
               new instance.
        """
        pulumi.set(__self__, "name", name)
        if databases is not None:
            pulumi.set(__self__, "databases", databases)
        if host is not None:
            pulumi.set(__self__, "host", host)
        if password is not None:
            pulumi.set(__self__, "password", password)

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        Username to be created on new instance. Changing this creates a
        new instance.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def databases(self) -> Optional[Sequence[builtins.str]]:
        """
        A list of databases that user will have access to. If not specified,
        user has access to all databases on th einstance. Changing this creates a new instance.
        """
        return pulumi.get(self, "databases")

    @property
    @pulumi.getter
    def host(self) -> Optional[builtins.str]:
        """
        An ip address or % sign indicating what ip addresses can connect with
        this user credentials. Changing this creates a new instance.
        """
        return pulumi.get(self, "host")

    @property
    @pulumi.getter
    def password(self) -> Optional[builtins.str]:
        """
        User's password. Changing this creates a
        new instance.
        """
        return pulumi.get(self, "password")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['KeypairArgs', 'Keypair']

@pulumi.input_type
class KeypairArgs:
    def __init__(__self__, *,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 public_key: Optional[pulumi.Input[builtins.str]] = None,
                 region: Optional[pulumi.Input[builtins.str]] = None,
                 user_id: Optional[pulumi.Input[builtins.str]] = None,
                 value_specs: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None):
        """
        The set of arguments for constructing a Keypair resource.
        :param pulumi.Input[builtins.str] name: A unique name for the keypair. Changing this creates a new
               keypair.
        :param pulumi.Input[builtins.str] public_key: A pregenerated OpenSSH-formatted public key.
               Changing this creates a new keypair. If a public key is not specified, then
               a public/private key pair will be automatically generated. If a pair is
               created, then destroying this resource means you will lose access to that
               keypair forever.
        :param pulumi.Input[builtins.str] region: The region in which to obtain the V2 Compute client.
               Keypairs are associated with accounts, but a Compute client is needed to
               create one. If omitted, the `region` argument of the provider is used.
               Changing this creates a new keypair.
        :param pulumi.Input[builtins.str] user_id: This allows administrative users to operate key-pairs
               of specified user ID. For this feature your need to have openstack microversion
               2.10 (Liberty) or later.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] value_specs: Map of additional options.
        """
        if name is not None:
            pulumi.set(__self__, "name", name)
        if public_key is not None:
            pulumi.set(__self__, "public_key", public_key)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if user_id is not None:
            pulumi.set(__self__, "user_id", user_id)
        if value_specs is not None:
            pulumi.set(__self__, "value_specs", value_specs)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        A unique name for the keypair. Changing this creates a new
        keypair.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="publicKey")
    def public_key(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        A pregenerated OpenSSH-formatted public key.
        Changing this creates a new keypair. If a public key is not specified, then
        a public/private key pair will be automatically generated. If a pair is
        created, then destroying this resource means you will lose access to that
        keypair forever.
        """
        return pulumi.get(self, "public_key")

    @public_key.setter
    def public_key(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "public_key", value)

    @property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The region in which to obtain the V2 Compute client.
        Keypairs are associated with accounts, but a Compute client is needed to
        create one. If omitted, the `region` argument of the provider is used.
        Changing this creates a new keypair.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "region", value)

    @property
    @pulumi.getter(name="userId")
    def user_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        This allows administrative users to operate key-pairs
        of specified user ID. For this feature your need to have openstack microversion
        2.10 (Liberty) or later.
        """
        return pulumi.get(self, "user_id")

    @user_id.setter
    def user_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "user_id", value)

    @property
    @pulumi.getter(name="valueSpecs")
    def value_specs(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]:
        """
        Map of additional options.
        """
        return pulumi.get(self, "value_specs")

    @value_specs.setter
    def value_specs(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "value_specs", value)


@pulumi.input_type
class _KeypairState:
    def __init__(__self__, *,
                 fingerprint: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 private_key: Optional[pulumi.Input[builtins.str]] = None,
                 public_key: Optional[pulumi.Input[builtins.str]] = None,
                 region: Optional[pulumi.Input[builtins.str]] = None,
                 user_id: Optional[pulumi.Input[builtins.str]] = None,
                 value_specs: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None):
        """
        Input properties used for looking up and filtering Keypair resources.
        :param pulumi.Input[builtins.str] fingerprint: The fingerprint of the public key.
        :param pulumi.Input[builtins.str] name: A unique name for the keypair. Changing this creates a new
               keypair.
        :param pulumi.Input[builtins.str] private_key: The generated private key when no public key is specified.
        :param pulumi.Input[builtins.str] public_key: A pregenerated OpenSSH-formatted public key.
               Changing this creates a new keypair. If a public key is not specified, then
               a public/private key pair will be automatically generated. If a pair is
               created, then destroying this resource means you will lose access to that
               keypair forever.
        :param pulumi.Input[builtins.str] region: The region in which to obtain the V2 Compute client.
               Keypairs are associated with accounts, but a Compute client is needed to
               create one. If omitted, the `region` argument of the provider is used.
               Changing this creates a new keypair.
        :param pulumi.Input[builtins.str] user_id: This allows administrative users to operate key-pairs
               of specified user ID. For this feature your need to have openstack microversion
               2.10 (Liberty) or later.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] value_specs: Map of additional options.
        """
        if fingerprint is not None:
            pulumi.set(__self__, "fingerprint", fingerprint)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if private_key is not None:
            pulumi.set(__self__, "private_key", private_key)
        if public_key is not None:
            pulumi.set(__self__, "public_key", public_key)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if user_id is not None:
            pulumi.set(__self__, "user_id", user_id)
        if value_specs is not None:
            pulumi.set(__self__, "value_specs", value_specs)

    @property
    @pulumi.getter
    def fingerprint(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The fingerprint of the public key.
        """
        return pulumi.get(self, "fingerprint")

    @fingerprint.setter
    def fingerprint(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "fingerprint", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        A unique name for the keypair. Changing this creates a new
        keypair.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="privateKey")
    def private_key(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The generated private key when no public key is specified.
        """
        return pulumi.get(self, "private_key")

    @private_key.setter
    def private_key(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "private_key", value)

    @property
    @pulumi.getter(name="publicKey")
    def public_key(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        A pregenerated OpenSSH-formatted public key.
        Changing this creates a new keypair. If a public key is not specified, then
        a public/private key pair will be automatically generated. If a pair is
        created, then destroying this resource means you will lose access to that
        keypair forever.
        """
        return pulumi.get(self, "public_key")

    @public_key.setter
    def public_key(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "public_key", value)

    @property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The region in which to obtain the V2 Compute client.
        Keypairs are associated with accounts, but a Compute client is needed to
        create one. If omitted, the `region` argument of the provider is used.
        Changing this creates a new keypair.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "region", value)

    @property
    @pulumi.getter(name="userId")
    def user_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        This allows administrative users to operate key-pairs
        of specified user ID. For this feature your need to have openstack microversion
        2.10 (Liberty) or later.
        """
        return pulumi.get(self, "user_id")

    @user_id.setter
    def user_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "user_id", value)

    @property
    @pulumi.getter(name="valueSpecs")
    def value_specs(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]:
        """
        Map of additional options.
        """
        return pulumi.get(self, "value_specs")

    @value_specs.setter
    def value_specs(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "value_specs", value)


class Keypair(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 public_key: Optional[pulumi.Input[builtins.str]] = None,
                 region: Optional[pulumi.Input[builtins.str]] = None,
                 user_id: Optional[pulumi.Input[builtins.str]] = None,
                 value_specs: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 __props__=None):
        """
        ## Example Usage

        ### Import an Existing Public Key

        ```python
        import pulumi
        import pulumi_openstack as openstack

        test_keypair = openstack.compute.Keypair("test-keypair",
            name="my-keypair",
            public_key="ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDAjpC1hwiOCCmKEWxJ4qzTTsJbKzndLotBCz5PcwtUnflmU+gHJtWMZKpuEGVi29h0A/+ydKek1O18k10Ff+4tyFjiHDQAnOfgWf7+b1yK+qDip3X1C0UPMbwHlTfSGWLGZqd9LvEFx9k3h/M+VtMvwR1lJ9LUyTAImnNjWG7TaIPmui30HvM2UiFEmqkr4ijq45MyX2+fLIePLRIF61p4whjHAQYufqyno3BS48icQb4p6iVEZPo4AE2o9oIyQvj2mx4dk5Y8CgSETOZTYDOR3rU2fZTRDRgPJDH9FWvQjF5tA0p3d9CoWWd2s6GKKbfoUIi8R/Db1BSPJwkqB")
        ```

        ### Generate a Public/Private Key Pair

        ```python
        import pulumi
        import pulumi_openstack as openstack

        test_keypair = openstack.compute.Keypair("test-keypair", name="my-keypair")
        ```

        ## Import

        Keypairs can be imported using the `name`, e.g.

        ```sh
        $ pulumi import openstack:compute/keypair:Keypair my-keypair test-keypair
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] name: A unique name for the keypair. Changing this creates a new
               keypair.
        :param pulumi.Input[builtins.str] public_key: A pregenerated OpenSSH-formatted public key.
               Changing this creates a new keypair. If a public key is not specified, then
               a public/private key pair will be automatically generated. If a pair is
               created, then destroying this resource means you will lose access to that
               keypair forever.
        :param pulumi.Input[builtins.str] region: The region in which to obtain the V2 Compute client.
               Keypairs are associated with accounts, but a Compute client is needed to
               create one. If omitted, the `region` argument of the provider is used.
               Changing this creates a new keypair.
        :param pulumi.Input[builtins.str] user_id: This allows administrative users to operate key-pairs
               of specified user ID. For this feature your need to have openstack microversion
               2.10 (Liberty) or later.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] value_specs: Map of additional options.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[KeypairArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Example Usage

        ### Import an Existing Public Key

        ```python
        import pulumi
        import pulumi_openstack as openstack

        test_keypair = openstack.compute.Keypair("test-keypair",
            name="my-keypair",
            public_key="ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDAjpC1hwiOCCmKEWxJ4qzTTsJbKzndLotBCz5PcwtUnflmU+gHJtWMZKpuEGVi29h0A/+ydKek1O18k10Ff+4tyFjiHDQAnOfgWf7+b1yK+qDip3X1C0UPMbwHlTfSGWLGZqd9LvEFx9k3h/M+VtMvwR1lJ9LUyTAImnNjWG7TaIPmui30HvM2UiFEmqkr4ijq45MyX2+fLIePLRIF61p4whjHAQYufqyno3BS48icQb4p6iVEZPo4AE2o9oIyQvj2mx4dk5Y8CgSETOZTYDOR3rU2fZTRDRgPJDH9FWvQjF5tA0p3d9CoWWd2s6GKKbfoUIi8R/Db1BSPJwkqB")
        ```

        ### Generate a Public/Private Key Pair

        ```python
        import pulumi
        import pulumi_openstack as openstack

        test_keypair = openstack.compute.Keypair("test-keypair", name="my-keypair")
        ```

        ## Import

        Keypairs can be imported using the `name`, e.g.

        ```sh
        $ pulumi import openstack:compute/keypair:Keypair my-keypair test-keypair
        ```

        :param str resource_name: The name of the resource.
        :param KeypairArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(KeypairArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 public_key: Optional[pulumi.Input[builtins.str]] = None,
                 region: Optional[pulumi.Input[builtins.str]] = None,
                 user_id: Optional[pulumi.Input[builtins.str]] = None,
                 value_specs: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = KeypairArgs.__new__(KeypairArgs)

            __props__.__dict__["name"] = name
            __props__.__dict__["public_key"] = public_key
            __props__.__dict__["region"] = region
            __props__.__dict__["user_id"] = user_id
            __props__.__dict__["value_specs"] = value_specs
            __props__.__dict__["fingerprint"] = None
            __props__.__dict__["private_key"] = None
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["privateKey"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(Keypair, __self__).__init__(
            'openstack:compute/keypair:Keypair',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            fingerprint: Optional[pulumi.Input[builtins.str]] = None,
            name: Optional[pulumi.Input[builtins.str]] = None,
            private_key: Optional[pulumi.Input[builtins.str]] = None,
            public_key: Optional[pulumi.Input[builtins.str]] = None,
            region: Optional[pulumi.Input[builtins.str]] = None,
            user_id: Optional[pulumi.Input[builtins.str]] = None,
            value_specs: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None) -> 'Keypair':
        """
        Get an existing Keypair resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] fingerprint: The fingerprint of the public key.
        :param pulumi.Input[builtins.str] name: A unique name for the keypair. Changing this creates a new
               keypair.
        :param pulumi.Input[builtins.str] private_key: The generated private key when no public key is specified.
        :param pulumi.Input[builtins.str] public_key: A pregenerated OpenSSH-formatted public key.
               Changing this creates a new keypair. If a public key is not specified, then
               a public/private key pair will be automatically generated. If a pair is
               created, then destroying this resource means you will lose access to that
               keypair forever.
        :param pulumi.Input[builtins.str] region: The region in which to obtain the V2 Compute client.
               Keypairs are associated with accounts, but a Compute client is needed to
               create one. If omitted, the `region` argument of the provider is used.
               Changing this creates a new keypair.
        :param pulumi.Input[builtins.str] user_id: This allows administrative users to operate key-pairs
               of specified user ID. For this feature your need to have openstack microversion
               2.10 (Liberty) or later.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] value_specs: Map of additional options.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _KeypairState.__new__(_KeypairState)

        __props__.__dict__["fingerprint"] = fingerprint
        __props__.__dict__["name"] = name
        __props__.__dict__["private_key"] = private_key
        __props__.__dict__["public_key"] = public_key
        __props__.__dict__["region"] = region
        __props__.__dict__["user_id"] = user_id
        __props__.__dict__["value_specs"] = value_specs
        return Keypair(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def fingerprint(self) -> pulumi.Output[builtins.str]:
        """
        The fingerprint of the public key.
        """
        return pulumi.get(self, "fingerprint")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[builtins.str]:
        """
        A unique name for the keypair. Changing this creates a new
        keypair.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="privateKey")
    def private_key(self) -> pulumi.Output[builtins.str]:
        """
        The generated private key when no public key is specified.
        """
        return pulumi.get(self, "private_key")

    @property
    @pulumi.getter(name="publicKey")
    def public_key(self) -> pulumi.Output[builtins.str]:
        """
        A pregenerated OpenSSH-formatted public key.
        Changing this creates a new keypair. If a public key is not specified, then
        a public/private key pair will be automatically generated. If a pair is
        created, then destroying this resource means you will lose access to that
        keypair forever.
        """
        return pulumi.get(self, "public_key")

    @property
    @pulumi.getter
    def region(self) -> pulumi.Output[builtins.str]:
        """
        The region in which to obtain the V2 Compute client.
        Keypairs are associated with accounts, but a Compute client is needed to
        create one. If omitted, the `region` argument of the provider is used.
        Changing this creates a new keypair.
        """
        return pulumi.get(self, "region")

    @property
    @pulumi.getter(name="userId")
    def user_id(self) -> pulumi.Output[builtins.str]:
        """
        This allows administrative users to operate key-pairs
        of specified user ID. For this feature your need to have openstack microversion
        2.10 (Liberty) or later.
        """
        return pulumi.get(self, "user_id")

    @property
    @pulumi.getter(name="valueSpecs")
    def value_specs(self) -> pulumi.Output[Optional[Mapping[str, builtins.str]]]:
        """
        Map of additional options.
        """
        return pulumi.get(self, "value_specs")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
from . import _utilities
import typing
# Export this package's modules as members:
from .bgpvpn_network_associate_v2 import *
from .bgpvpn_port_associate_v2 import *
from .bgpvpn_router_associate_v2 import *
from .bgpvpn_v2 import *
from .get_fw_group_v2 import *
from .get_fw_policy_v2 import *
from .get_fw_rule_v2 import *
from .lb_flavorprofile_v2 import *
from .lb_loadbalancer_v2 import *
from .provider import *
from ._inputs import *
from . import outputs

# Make subpackages available:
if typing.TYPE_CHECKING:
    import pulumi_openstack.blockstorage as __blockstorage
    blockstorage = __blockstorage
    import pulumi_openstack.compute as __compute
    compute = __compute
    import pulumi_openstack.config as __config
    config = __config
    import pulumi_openstack.containerinfra as __containerinfra
    containerinfra = __containerinfra
    import pulumi_openstack.database as __database
    database = __database
    import pulumi_openstack.dns as __dns
    dns = __dns
    import pulumi_openstack.firewall as __firewall
    firewall = __firewall
    import pulumi_openstack.identity as __identity
    identity = __identity
    import pulumi_openstack.images as __images
    images = __images
    import pulumi_openstack.keymanager as __keymanager
    keymanager = __keymanager
    import pulumi_openstack.loadbalancer as __loadbalancer
    loadbalancer = __loadbalancer
    import pulumi_openstack.networking as __networking
    networking = __networking
    import pulumi_openstack.objectstorage as __objectstorage
    objectstorage = __objectstorage
    import pulumi_openstack.orchestration as __orchestration
    orchestration = __orchestration
    import pulumi_openstack.sharedfilesystem as __sharedfilesystem
    sharedfilesystem = __sharedfilesystem
    import pulumi_openstack.vpnaas as __vpnaas
    vpnaas = __vpnaas
else:
    blockstorage = _utilities.lazy_import('pulumi_openstack.blockstorage')
    compute = _utilities.lazy_import('pulumi_openstack.compute')
    config = _utilities.lazy_import('pulumi_openstack.config')
    containerinfra = _utilities.lazy_import('pulumi_openstack.containerinfra')
    database = _utilities.lazy_import('pulumi_openstack.database')
    dns = _utilities.lazy_import('pulumi_openstack.dns')
    firewall = _utilities.lazy_import('pulumi_openstack.firewall')
    identity = _utilities.lazy_import('pulumi_openstack.identity')
    images = _utilities.lazy_import('pulumi_openstack.images')
    keymanager = _utilities.lazy_import('pulumi_openstack.keymanager')
    loadbalancer = _utilities.lazy_import('pulumi_openstack.loadbalancer')
    networking = _utilities.lazy_import('pulumi_openstack.networking')
    objectstorage = _utilities.lazy_import('pulumi_openstack.objectstorage')
    orchestration = _utilities.lazy_import('pulumi_openstack.orchestration')
    sharedfilesystem = _utilities.lazy_import('pulumi_openstack.sharedfilesystem')
    vpnaas = _utilities.lazy_import('pulumi_openstack.vpnaas')

_utilities.register(
    resource_modules="""
[
 {
  "pkg": "openstack",
  "mod": "blockstorage/qosAssociationV3",
  "fqn": "pulumi_openstack.blockstorage",
  "classes": {
   "openstack:blockstorage/qosAssociationV3:QosAssociationV3": "QosAssociationV3"
  }
 },
 {
  "pkg": "openstack",
  "mod": "blockstorage/qosV3",
  "fqn": "pulumi_openstack.blockstorage",
  "classes": {
   "openstack:blockstorage/qosV3:QosV3": "QosV3"
  }
 },
 {
  "pkg": "openstack",
  "mod": "blockstorage/quoteSetV3",
  "fqn": "pulumi_openstack.blockstorage",
  "classes": {
   "openstack:blockstorage/quoteSetV3:QuoteSetV3": "QuoteSetV3"
  }
 },
 {
  "pkg": "openstack",
  "mod": "blockstorage/volume",
  "fqn": "pulumi_openstack.blockstorage",
  "classes": {
   "openstack:blockstorage/volume:Volume": "Volume"
  }
 },
 {
  "pkg": "openstack",
  "mod": "blockstorage/volumeAttach",
  "fqn": "pulumi_openstack.blockstorage",
  "classes": {
   "openstack:blockstorage/volumeAttach:VolumeAttach": "VolumeAttach"
  }
 },
 {
  "pkg": "openstack",
  "mod": "blockstorage/volumeTypeAccessV3",
  "fqn": "pulumi_openstack.blockstorage",
  "classes": {
   "openstack:blockstorage/volumeTypeAccessV3:VolumeTypeAccessV3": "VolumeTypeAccessV3"
  }
 },
 {
  "pkg": "openstack",
  "mod": "blockstorage/volumeTypeV3",
  "fqn": "pulumi_openstack.blockstorage",
  "classes": {
   "openstack:blockstorage/volumeTypeV3:VolumeTypeV3": "VolumeTypeV3"
  }
 },
 {
  "pkg": "openstack",
  "mod": "compute/aggregateV2",
  "fqn": "pulumi_openstack.compute",
  "classes": {
   "openstack:compute/aggregateV2:AggregateV2": "AggregateV2"
  }
 },
 {
  "pkg": "openstack",
  "mod": "compute/flavor",
  "fqn": "pulumi_openstack.compute",
  "classes": {
   "openstack:compute/flavor:Flavor": "Flavor"
  }
 },
 {
  "pkg": "openstack",
  "mod": "compute/flavorAccess",
  "fqn": "pulumi_openstack.compute",
  "classes": {
   "openstack:compute/flavorAccess:FlavorAccess": "FlavorAccess"
  }
 },
 {
  "pkg": "openstack",
  "mod": "compute/instance",
  "fqn": "pulumi_openstack.compute",
  "classes": {
   "openstack:compute/instance:Instance": "Instance"
  }
 },
 {
  "pkg": "openstack",
  "mod": "compute/interfaceAttach",
  "fqn": "pulumi_openstack.compute",
  "classes": {
   "openstack:compute/interfaceAttach:InterfaceAttach": "InterfaceAttach"
  }
 },
 {
  "pkg": "openstack",
  "mod": "compute/keypair",
  "fqn": "pulumi_openstack.compute",
  "classes": {
   "openstack:compute/keypair:Keypair": "Keypair"
  }
 },
 {
  "pkg": "openstack",
  "mod": "compute/quotaSetV2",
  "fqn": "pulumi_openstack.compute",
  "classes": {
   "openstack:compute/quotaSetV2:QuotaSetV2": "QuotaSetV2"
  }
 },
 {
  "pkg": "openstack",
  "mod": "compute/serverGroup",
  "fqn": "pulumi_openstack.compute",
  "classes": {
   "openstack:compute/serverGroup:ServerGroup": "ServerGroup"
  }
 },
 {
  "pkg": "openstack",
  "mod": "compute/volumeAttach",
  "fqn": "pulumi_openstack.compute",
  "classes": {
   "openstack:compute/volumeAttach:VolumeAttach": "VolumeAttach"
  }
 },
 {
  "pkg": "openstack",
  "mod": "containerinfra/cluster",
  "fqn": "pulumi_openstack.containerinfra",
  "classes": {
   "openstack:containerinfra/cluster:Cluster": "Cluster"
  }
 },
 {
  "pkg": "openstack",
  "mod": "containerinfra/clusterTemplate",
  "fqn": "pulumi_openstack.containerinfra",
  "classes": {
   "openstack:containerinfra/clusterTemplate:ClusterTemplate": "ClusterTemplate"
  }
 },
 {
  "pkg": "openstack",
  "mod": "containerinfra/nodeGroup",
  "fqn": "pulumi_openstack.containerinfra",
  "classes": {
   "openstack:containerinfra/nodeGroup:NodeGroup": "NodeGroup"
  }
 },
 {
  "pkg": "openstack",
  "mod": "database/configuration",
  "fqn": "pulumi_openstack.database",
  "classes": {
   "openstack:database/configuration:Configuration": "Configuration"
  }
 },
 {
  "pkg": "openstack",
  "mod": "database/database",
  "fqn": "pulumi_openstack.database",
  "classes": {
   "openstack:database/database:Database": "Database"
  }
 },
 {
  "pkg": "openstack",
  "mod": "database/instance",
  "fqn": "pulumi_openstack.database",
  "classes": {
   "openstack:database/instance:Instance": "Instance"
  }
 },
 {
  "pkg": "openstack",
  "mod": "database/user",
  "fqn": "pulumi_openstack.database",
  "classes": {
   "openstack:database/user:User": "User"
  }
 },
 {
  "pkg": "openstack",
  "mod": "dns/recordSet",
  "fqn": "pulumi_openstack.dns",
  "classes": {
   "openstack:dns/recordSet:RecordSet": "RecordSet"
  }
 },
 {
  "pkg": "openstack",
  "mod": "dns/transferAccept",
  "fqn": "pulumi_openstack.dns",
  "classes": {
   "openstack:dns/transferAccept:TransferAccept": "TransferAccept"
  }
 },
 {
  "pkg": "openstack",
  "mod": "dns/transferRequest",
  "fqn": "pulumi_openstack.dns",
  "classes": {
   "openstack:dns/transferRequest:TransferRequest": "TransferRequest"
  }
 },
 {
  "pkg": "openstack",
  "mod": "dns/zone",
  "fqn": "pulumi_openstack.dns",
  "classes": {
   "openstack:dns/zone:Zone": "Zone"
  }
 },
 {
  "pkg": "openstack",
  "mod": "firewall/groupV2",
  "fqn": "pulumi_openstack.firewall",
  "classes": {
   "openstack:firewall/groupV2:GroupV2": "GroupV2"
  }
 },
 {
  "pkg": "openstack",
  "mod": "firewall/policyV2",
  "fqn": "pulumi_openstack.firewall",
  "classes": {
   "openstack:firewall/policyV2:PolicyV2": "PolicyV2"
  }
 },
 {
  "pkg": "openstack",
  "mod": "firewall/ruleV2",
  "fqn": "pulumi_openstack.firewall",
  "classes": {
   "openstack:firewall/ruleV2:RuleV2": "RuleV2"
  }
 },
 {
  "pkg": "openstack",
  "mod": "identity/applicationCredential",
  "fqn": "pulumi_openstack.identity",
  "classes": {
   "openstack:identity/applicationCredential:ApplicationCredential": "ApplicationCredential"
  }
 },
 {
  "pkg": "openstack",
  "mod": "identity/ec2CredentialV3",
  "fqn": "pulumi_openstack.identity",
  "classes": {
   "openstack:identity/ec2CredentialV3:Ec2CredentialV3": "Ec2CredentialV3"
  }
 },
 {
  "pkg": "openstack",
  "mod": "identity/endpointV3",
  "fqn": "pulumi_openstack.identity",
  "classes": {
   "openstack:identity/endpointV3:EndpointV3": "EndpointV3"
  }
 },
 {
  "pkg": "openstack",
  "mod": "identity/groupV3",
  "fqn": "pulumi_openstack.identity",
  "classes": {
   "openstack:identity/groupV3:GroupV3": "GroupV3"
  }
 },
 {
  "pkg": "openstack",
  "mod": "identity/inheritRoleAssignment",
  "fqn": "pulumi_openstack.identity",
  "classes": {
   "openstack:identity/inheritRoleAssignment:InheritRoleAssignment": "InheritRoleAssignment"
  }
 },
 {
  "pkg": "openstack",
  "mod": "identity/project",
  "fqn": "pulumi_openstack.identity",
  "classes": {
   "openstack:identity/project:Project": "Project"
  }
 },
 {
  "pkg": "openstack",
  "mod": "identity/role",
  "fqn": "pulumi_openstack.identity",
  "classes": {
   "openstack:identity/role:Role": "Role"
  }
 },
 {
  "pkg": "openstack",
  "mod": "identity/roleAssignment",
  "fqn": "pulumi_openstack.identity",
  "classes": {
   "openstack:identity/roleAssignment:RoleAssignment": "RoleAssignment"
  }
 },
 {
  "pkg": "openstack",
  "mod": "identity/serviceV3",
  "fqn": "pulumi_openstack.identity",
  "classes": {
   "openstack:identity/serviceV3:ServiceV3": "ServiceV3"
  }
 },
 {
  "pkg": "openstack",
  "mod": "identity/user",
  "fqn": "pulumi_openstack.identity",
  "classes": {
   "openstack:identity/user:User": "User"
  }
 },
 {
  "pkg": "openstack",
  "mod": "identity/userMembershipV3",
  "fqn": "pulumi_openstack.identity",
  "classes": {
   "openstack:identity/userMembershipV3:UserMembershipV3": "UserMembershipV3"
  }
 },
 {
  "pkg": "openstack",
  "mod": "images/image",
  "fqn": "pulumi_openstack.images",
  "classes": {
   "openstack:images/image:Image": "Image"
  }
 },
 {
  "pkg": "openstack",
  "mod": "images/imageAccess",
  "fqn": "pulumi_openstack.images",
  "classes": {
   "openstack:images/imageAccess:ImageAccess": "ImageAccess"
  }
 },
 {
  "pkg": "openstack",
  "mod": "images/imageAccessAccept",
  "fqn": "pulumi_openstack.images",
  "classes": {
   "openstack:images/imageAccessAccept:ImageAccessAccept": "ImageAccessAccept"
  }
 },
 {
  "pkg": "openstack",
  "mod": "index/bgpvpnNetworkAssociateV2",
  "fqn": "pulumi_openstack",
  "classes": {
   "openstack:index/bgpvpnNetworkAssociateV2:BgpvpnNetworkAssociateV2": "BgpvpnNetworkAssociateV2"
  }
 },
 {
  "pkg": "openstack",
  "mod": "index/bgpvpnPortAssociateV2",
  "fqn": "pulumi_openstack",
  "classes": {
   "openstack:index/bgpvpnPortAssociateV2:BgpvpnPortAssociateV2": "BgpvpnPortAssociateV2"
  }
 },
 {
  "pkg": "openstack",
  "mod": "index/bgpvpnRouterAssociateV2",
  "fqn": "pulumi_openstack",
  "classes": {
   "openstack:index/bgpvpnRouterAssociateV2:BgpvpnRouterAssociateV2": "BgpvpnRouterAssociateV2"
  }
 },
 {
  "pkg": "openstack",
  "mod": "index/bgpvpnV2",
  "fqn": "pulumi_openstack",
  "classes": {
   "openstack:index/bgpvpnV2:BgpvpnV2": "BgpvpnV2"
  }
 },
 {
  "pkg": "openstack",
  "mod": "index/lbFlavorprofileV2",
  "fqn": "pulumi_openstack",
  "classes": {
   "openstack:index/lbFlavorprofileV2:LbFlavorprofileV2": "LbFlavorprofileV2"
  }
 },
 {
  "pkg": "openstack",
  "mod": "index/lbLoadbalancerV2",
  "fqn": "pulumi_openstack",
  "classes": {
   "openstack:index/lbLoadbalancerV2:LbLoadbalancerV2": "LbLoadbalancerV2"
  }
 },
 {
  "pkg": "openstack",
  "mod": "keymanager/containerV1",
  "fqn": "pulumi_openstack.keymanager",
  "classes": {
   "openstack:keymanager/containerV1:ContainerV1": "ContainerV1"
  }
 },
 {
  "pkg": "openstack",
  "mod": "keymanager/orderV1",
  "fqn": "pulumi_openstack.keymanager",
  "classes": {
   "openstack:keymanager/orderV1:OrderV1": "OrderV1"
  }
 },
 {
  "pkg": "openstack",
  "mod": "keymanager/secretV1",
  "fqn": "pulumi_openstack.keymanager",
  "classes": {
   "openstack:keymanager/secretV1:SecretV1": "SecretV1"
  }
 },
 {
  "pkg": "openstack",
  "mod": "loadbalancer/l7PolicyV2",
  "fqn": "pulumi_openstack.loadbalancer",
  "classes": {
   "openstack:loadbalancer/l7PolicyV2:L7PolicyV2": "L7PolicyV2"
  }
 },
 {
  "pkg": "openstack",
  "mod": "loadbalancer/l7RuleV2",
  "fqn": "pulumi_openstack.loadbalancer",
  "classes": {
   "openstack:loadbalancer/l7RuleV2:L7RuleV2": "L7RuleV2"
  }
 },
 {
  "pkg": "openstack",
  "mod": "loadbalancer/listener",
  "fqn": "pulumi_openstack.loadbalancer",
  "classes": {
   "openstack:loadbalancer/listener:Listener": "Listener"
  }
 },
 {
  "pkg": "openstack",
  "mod": "loadbalancer/member",
  "fqn": "pulumi_openstack.loadbalancer",
  "classes": {
   "openstack:loadbalancer/member:Member": "Member"
  }
 },
 {
  "pkg": "openstack",
  "mod": "loadbalancer/members",
  "fqn": "pulumi_openstack.loadbalancer",
  "classes": {
   "openstack:loadbalancer/members:Members": "Members"
  }
 },
 {
  "pkg": "openstack",
  "mod": "loadbalancer/monitor",
  "fqn": "pulumi_openstack.loadbalancer",
  "classes": {
   "openstack:loadbalancer/monitor:Monitor": "Monitor"
  }
 },
 {
  "pkg": "openstack",
  "mod": "loadbalancer/pool",
  "fqn": "pulumi_openstack.loadbalancer",
  "classes": {
   "openstack:loadbalancer/pool:Pool": "Pool"
  }
 },
 {
  "pkg": "openstack",
  "mod": "loadbalancer/quota",
  "fqn": "pulumi_openstack.loadbalancer",
  "classes": {
   "openstack:loadbalancer/quota:Quota": "Quota"
  }
 },
 {
  "pkg": "openstack",
  "mod": "networking/addressScope",
  "fqn": "pulumi_openstack.networking",
  "classes": {
   "openstack:networking/addressScope:AddressScope": "AddressScope"
  }
 },
 {
  "pkg": "openstack",
  "mod": "networking/floatingIp",
  "fqn": "pulumi_openstack.networking",
  "classes": {
   "openstack:networking/floatingIp:FloatingIp": "FloatingIp"
  }
 },
 {
  "pkg": "openstack",
  "mod": "networking/floatingIpAssociate",
  "fqn": "pulumi_openstack.networking",
  "classes": {
   "openstack:networking/floatingIpAssociate:FloatingIpAssociate": "FloatingIpAssociate"
  }
 },
 {
  "pkg": "openstack",
  "mod": "networking/network",
  "fqn": "pulumi_openstack.networking",
  "classes": {
   "openstack:networking/network:Network": "Network"
  }
 },
 {
  "pkg": "openstack",
  "mod": "networking/port",
  "fqn": "pulumi_openstack.networking",
  "classes": {
   "openstack:networking/port:Port": "Port"
  }
 },
 {
  "pkg": "openstack",
  "mod": "networking/portForwardingV2",
  "fqn": "pulumi_openstack.networking",
  "classes": {
   "openstack:networking/portForwardingV2:PortForwardingV2": "PortForwardingV2"
  }
 },
 {
  "pkg": "openstack",
  "mod": "networking/portSecGroupAssociate",
  "fqn": "pulumi_openstack.networking",
  "classes": {
   "openstack:networking/portSecGroupAssociate:PortSecGroupAssociate": "PortSecGroupAssociate"
  }
 },
 {
  "pkg": "openstack",
  "mod": "networking/qosBandwidthLimitRule",
  "fqn": "pulumi_openstack.networking",
  "classes": {
   "openstack:networking/qosBandwidthLimitRule:QosBandwidthLimitRule": "QosBandwidthLimitRule"
  }
 },
 {
  "pkg": "openstack",
  "mod": "networking/qosDscpMarkingRule",
  "fqn": "pulumi_openstack.networking",
  "classes": {
   "openstack:networking/qosDscpMarkingRule:QosDscpMarkingRule": "QosDscpMarkingRule"
  }
 },
 {
  "pkg": "openstack",
  "mod": "networking/qosMinimumBandwidthRule",
  "fqn": "pulumi_openstack.networking",
  "classes": {
   "openstack:networking/qosMinimumBandwidthRule:QosMinimumBandwidthRule": "QosMinimumBandwidthRule"
  }
 },
 {
  "pkg": "openstack",
  "mod": "networking/qosPolicy",
  "fqn": "pulumi_openstack.networking",
  "classes": {
   "openstack:networking/qosPolicy:QosPolicy": "QosPolicy"
  }
 },
 {
  "pkg": "openstack",
  "mod": "networking/quotaV2",
  "fqn": "pulumi_openstack.networking",
  "classes": {
   "openstack:networking/quotaV2:QuotaV2": "QuotaV2"
  }
 },
 {
  "pkg": "openstack",
  "mod": "networking/rbacPolicyV2",
  "fqn": "pulumi_openstack.networking",
  "classes": {
   "openstack:networking/rbacPolicyV2:RbacPolicyV2": "RbacPolicyV2"
  }
 },
 {
  "pkg": "openstack",
  "mod": "networking/router",
  "fqn": "pulumi_openstack.networking",
  "classes": {
   "openstack:networking/router:Router": "Router"
  }
 },
 {
  "pkg": "openstack",
  "mod": "networking/routerInterface",
  "fqn": "pulumi_openstack.networking",
  "classes": {
   "openstack:networking/routerInterface:RouterInterface": "RouterInterface"
  }
 },
 {
  "pkg": "openstack",
  "mod": "networking/routerRoute",
  "fqn": "pulumi_openstack.networking",
  "classes": {
   "openstack:networking/routerRoute:RouterRoute": "RouterRoute"
  }
 },
 {
  "pkg": "openstack",
  "mod": "networking/secGroup",
  "fqn": "pulumi_openstack.networking",
  "classes": {
   "openstack:networking/secGroup:SecGroup": "SecGroup"
  }
 },
 {
  "pkg": "openstack",
  "mod": "networking/secGroupRule",
  "fqn": "pulumi_openstack.networking",
  "classes": {
   "openstack:networking/secGroupRule:SecGroupRule": "SecGroupRule"
  }
 },
 {
  "pkg": "openstack",
  "mod": "networking/subnet",
  "fqn": "pulumi_openstack.networking",
  "classes": {
   "openstack:networking/subnet:Subnet": "Subnet"
  }
 },
 {
  "pkg": "openstack",
  "mod": "networking/subnetPool",
  "fqn": "pulumi_openstack.networking",
  "classes": {
   "openstack:networking/subnetPool:SubnetPool": "SubnetPool"
  }
 },
 {
  "pkg": "openstack",
  "mod": "networking/subnetRoute",
  "fqn": "pulumi_openstack.networking",
  "classes": {
   "openstack:networking/subnetRoute:SubnetRoute": "SubnetRoute"
  }
 },
 {
  "pkg": "openstack",
  "mod": "networking/trunk",
  "fqn": "pulumi_openstack.networking",
  "classes": {
   "openstack:networking/trunk:Trunk": "Trunk"
  }
 },
 {
  "pkg": "openstack",
  "mod": "objectstorage/accountV1",
  "fqn": "pulumi_openstack.objectstorage",
  "classes": {
   "openstack:objectstorage/accountV1:AccountV1": "AccountV1"
  }
 },
 {
  "pkg": "openstack",
  "mod": "objectstorage/container",
  "fqn": "pulumi_openstack.objectstorage",
  "classes": {
   "openstack:objectstorage/container:Container": "Container"
  }
 },
 {
  "pkg": "openstack",
  "mod": "objectstorage/containerObject",
  "fqn": "pulumi_openstack.objectstorage",
  "classes": {
   "openstack:objectstorage/containerObject:ContainerObject": "ContainerObject"
  }
 },
 {
  "pkg": "openstack",
  "mod": "objectstorage/tempUrl",
  "fqn": "pulumi_openstack.objectstorage",
  "classes": {
   "openstack:objectstorage/tempUrl:TempUrl": "TempUrl"
  }
 },
 {
  "pkg": "openstack",
  "mod": "orchestration/stackV1",
  "fqn": "pulumi_openstack.orchestration",
  "classes": {
   "openstack:orchestration/stackV1:StackV1": "StackV1"
  }
 },
 {
  "pkg": "openstack",
  "mod": "sharedfilesystem/securityService",
  "fqn": "pulumi_openstack.sharedfilesystem",
  "classes": {
   "openstack:sharedfilesystem/securityService:SecurityService": "SecurityService"
  }
 },
 {
  "pkg": "openstack",
  "mod": "sharedfilesystem/share",
  "fqn": "pulumi_openstack.sharedfilesystem",
  "classes": {
   "openstack:sharedfilesystem/share:Share": "Share"
  }
 },
 {
  "pkg": "openstack",
  "mod": "sharedfilesystem/shareAccess",
  "fqn": "pulumi_openstack.sharedfilesystem",
  "classes": {
   "openstack:sharedfilesystem/shareAccess:ShareAccess": "ShareAccess"
  }
 },
 {
  "pkg": "openstack",
  "mod": "sharedfilesystem/shareNetwork",
  "fqn": "pulumi_openstack.sharedfilesystem",
  "classes": {
   "openstack:sharedfilesystem/shareNetwork:ShareNetwork": "ShareNetwork"
  }
 },
 {
  "pkg": "openstack",
  "mod": "vpnaas/endpointGroup",
  "fqn": "pulumi_openstack.vpnaas",
  "classes": {
   "openstack:vpnaas/endpointGroup:EndpointGroup": "EndpointGroup"
  }
 },
 {
  "pkg": "openstack",
  "mod": "vpnaas/ikePolicy",
  "fqn": "pulumi_openstack.vpnaas",
  "classes": {
   "openstack:vpnaas/ikePolicy:IkePolicy": "IkePolicy"
  }
 },
 {
  "pkg": "openstack",
  "mod": "vpnaas/ipSecPolicy",
  "fqn": "pulumi_openstack.vpnaas",
  "classes": {
   "openstack:vpnaas/ipSecPolicy:IpSecPolicy": "IpSecPolicy"
  }
 },
 {
  "pkg": "openstack",
  "mod": "vpnaas/service",
  "fqn": "pulumi_openstack.vpnaas",
  "classes": {
   "openstack:vpnaas/service:Service": "Service"
  }
 },
 {
  "pkg": "openstack",
  "mod": "vpnaas/siteConnection",
  "fqn": "pulumi_openstack.vpnaas",
  "classes": {
   "openstack:vpnaas/siteConnection:SiteConnection": "SiteConnection"
  }
 }
]
""",
    resource_packages="""
[
 {
  "pkg": "openstack",
  "token": "pulumi:providers:openstack",
  "fqn": "pulumi_openstack",
  "class": "Provider"
 }
]
"""
)
